@@ -1,5 +1,7 @@
 import os
+import logging
 import argparse
+from pkg_resources import resource_filename
 from functools import partial
 from shutil import copytree, rmtree, copy
 from pds_github_util.branches.git_actions import loop_checkout_on_branch
@@ -7,9 +9,12 @@ from pds_github_util.gh_pages.summary import write_build_summary
 from pds_github_util.gh_pages.root_index import update_index
 
 
+logging.basicConfig(level=logging.INFO)
+logger = logging.getLogger()
+
 def copy_resources():
-    resources = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                             'resources')
+    logger.info("write static resources (img, config)...")
+    resources = resource_filename(__name__, 'resources')
     for f in os.listdir(resources):
         i_p = os.path.join(resources, f)
         o_p = os.path.join(os.getcwd(), f)
@@ -25,9 +30,6 @@ def copy_resources():
 
 def main():
     parser = argparse.ArgumentParser(description='Create new snapshot release')
-    parser.add_argument('--output', dest='output',
-                        default='.',
-                        help='markdown output file name')
     parser.add_argument('--token', dest='token',
                         help='github personal access token')
     args = parser.parse_args()
@@ -54,10 +56,7 @@ def main():
                             token=args.token,
                             local_git_tmp_dir='/tmp')
 
-
-
-    print(args.output)
-
+    update_index(os.getcwd())
 
 
 
